Raz has been created to extract insights from bunch of data.
It was written using pandas, numpy and scikit-learn to use very basic steps in Machine Learning which can be understood by anyone, even ML beginners.
Please send me your feedback to this email: siadatisaman@gmail.com



....................................................................

Raz means 'secret' in the Persian language. 

